pitchtools.list_numbered_inversion_equivalent_interval_classes_pairwise
=======================================================================

.. autofunction:: abjad.tools.pitchtools.list_numbered_inversion_equivalent_interval_classes_pairwise.list_numbered_inversion_equivalent_interval_classes_pairwise
